@@ -8,29 +8,28 @@ from scipy.optimize import root_scalar, root, fixed_point
 MIN_ANGLE = 1e-6
 MAX_ANGLE = np.pi / 2 - MIN_ANGLE
 
+__all__ = ["solve_box_like", "solve_r123", "solve_r124", "solve_r1234"]
+
 
 def solve_r124(
-        r1: float,
-
-        r2: Optional[float],
-        depth: Optional[float],
-        width: Optional[float],
-
-        pad_angle: float,
-
-        flank_angle: Optional[float] = None,
-        flank_width: Optional[float] = None,
-        flank_height: Optional[float] = None,
-        flank_length: Optional[float] = None,
-
-        r4: float = 0,
-        indent: float = 0,
+    r1: float,
+    r2: Optional[float],
+    depth: Optional[float],
+    width: Optional[float],
+    pad_angle: float,
+    flank_angle: Optional[float] = None,
+    flank_width: Optional[float] = None,
+    flank_height: Optional[float] = None,
+    flank_length: Optional[float] = None,
+    r4: float = 0,
+    indent: float = 0,
 ):
     def l23(_alpha):
         return r1 * np.tan((_alpha + pad_angle) / 2)
 
     if flank_angle is None:
         if flank_length is not None:
+
             def fw(_alpha):
                 return flank_length * np.cos(_alpha)
 
@@ -38,6 +37,7 @@ def solve_r124(
                 return flank_length * np.sin(_alpha)
 
         elif flank_width is not None:
+
             def fw(_alpha):
                 return flank_width
 
@@ -45,6 +45,7 @@ def solve_r124(
                 return flank_width * np.tan(_alpha)
 
         elif flank_height is not None:
+
             def fw(_alpha):
                 return flank_height / np.tan(_alpha)
 
@@ -52,6 +53,7 @@ def solve_r124(
                 return flank_height
 
         else:
+
             def fw(_alpha):
                 return 0
 
@@ -59,6 +61,7 @@ def solve_r124(
                 return 0
 
         if width is None:
+
             def f(_alpha):
                 return depth - r2 * (1 - np.cos(_alpha)) - l23(_alpha) * np.sin(_alpha) - fh(_alpha)
 
@@ -69,8 +72,11 @@ def solve_r124(
 
             def f(_alpha):
                 return (
-                        width / 2 - r2 * np.sin(_alpha) - l23(_alpha) * np.cos(_alpha)
-                        - fw(_alpha) - (r2 + r4) * np.sin(alpha4)
+                    width / 2
+                    - r2 * np.sin(_alpha)
+                    - l23(_alpha) * np.cos(_alpha)
+                    - fw(_alpha)
+                    - (r2 + r4) * np.sin(alpha4)
                 )
 
             raster = np.linspace(MIN_ANGLE, MAX_ANGLE, 100)
@@ -80,13 +86,17 @@ def solve_r124(
             flank_angle = root_scalar(f, bracket=(lower, upper)).root
 
         elif r2 is None:
+
             def f(_alpha):
                 _r2 = (depth - l23(_alpha) * np.sin(_alpha) - fh(_alpha)) / (1 - np.cos(_alpha))
                 _alpha4 = np.arccos(1 - indent / (_r2 + r4))
 
                 return (
-                        width / 2 - _r2 * np.sin(_alpha) - l23(_alpha) * np.cos(_alpha)
-                        - fw(_alpha) - (_r2 + r4) * np.sin(_alpha4)
+                    width / 2
+                    - _r2 * np.sin(_alpha)
+                    - l23(_alpha) * np.cos(_alpha)
+                    - fw(_alpha)
+                    - (_r2 + r4) * np.sin(_alpha4)
                 )
 
             flank_angle = root_scalar(f, bracket=(MIN_ANGLE, MAX_ANGLE)).root
@@ -99,23 +109,22 @@ def solve_r124(
 
         if width is None:
             width = 2 * (
-                    r2 * np.sin(flank_angle)
-                    + (depth - r2 * (1 - np.cos(flank_angle))) / np.tan(flank_angle)
-                    + (r2 + r4) * np.sin(alpha4)
+                r2 * np.sin(flank_angle)
+                + (depth - r2 * (1 - np.cos(flank_angle))) / np.tan(flank_angle)
+                + (r2 + r4) * np.sin(alpha4)
             )
 
         elif depth is None:
-            depth = (
-                    r2 * (1 - np.cos(flank_angle))
-                    + (width / 2 - r2 * np.sin(flank_angle) - (r2 + r4) * np.sin(alpha4)) * np.tan(flank_angle)
-            )
+            depth = r2 * (1 - np.cos(flank_angle)) + (
+                width / 2 - r2 * np.sin(flank_angle) - (r2 + r4) * np.sin(alpha4)
+            ) * np.tan(flank_angle)
 
     else:
+
         def f(_r2):
             _alpha4 = np.arccos(1 - indent / (_r2 + r4))
-            return (
-                    (depth - width / 2 * np.tan(flank_angle) + r4 * np.sin(_alpha4))
-                    / (1 - np.cos(flank_angle) - np.sin(flank_angle) * np.tan(flank_angle) - np.sin(_alpha4))
+            return (depth - width / 2 * np.tan(flank_angle) + r4 * np.sin(_alpha4)) / (
+                1 - np.cos(flank_angle) - np.sin(flank_angle) * np.tan(flank_angle) - np.sin(_alpha4)
             )
 
         r2 = fixed_point(f, width if width > depth else depth)
@@ -130,18 +139,16 @@ def solve_r124(
 
 
 def solve_r123(
-        r1: float,
-        r2: float,
-        r3: float,
-        depth: float,
-        width: float,
-
-        pad_angle: float,
-
-        flank_angle: Optional[float] = None,
-        flank_width: Optional[float] = None,
-        flank_height: Optional[float] = None,
-        flank_length: Optional[float] = None,
+    r1: float,
+    r2: float,
+    r3: float,
+    depth: float,
+    width: float,
+    pad_angle: float,
+    flank_angle: Optional[float] = None,
+    flank_width: Optional[float] = None,
+    flank_height: Optional[float] = None,
+    flank_length: Optional[float] = None,
 ):
     def l23(_alpha):
         return r1 * np.tan((_alpha + pad_angle) / 2)
@@ -150,6 +157,7 @@ def solve_r123(
 
     if flank_angle is None:
         if flank_length is not None:
+
             def fw(_alpha):
                 return flank_length * np.cos(_alpha)
 
@@ -157,6 +165,7 @@ def solve_r123(
                 return flank_length * np.sin(_alpha)
 
         elif flank_width is not None:
+
             def fw(_alpha):
                 return flank_width
 
@@ -164,6 +173,7 @@ def solve_r123(
                 return flank_width * np.tan(_alpha)
 
         elif flank_height is not None:
+
             def fw(_alpha):
                 return flank_height / np.tan(_alpha)
 
@@ -171,6 +181,7 @@ def solve_r123(
                 return flank_height
 
         else:
+
             def fw(_alpha):
                 return 0
 
@@ -186,18 +197,26 @@ def solve_r123(
             return np.array(
                 [
                     (
-                            depth - r3 + r32 * np.cos(_alpha3) + r2 * np.sin(_gamma)
-                            - fh(_flank_angle) - l23(_flank_angle) * np.sin(_flank_angle)
+                        depth
+                        - r3
+                        + r32 * np.cos(_alpha3)
+                        + r2 * np.sin(_gamma)
+                        - fh(_flank_angle)
+                        - l23(_flank_angle) * np.sin(_flank_angle)
                     ),
                     (
-                            width / 2 - r32 * np.sin(_alpha3) - r2 * np.cos(_gamma)
-                            - fw(_flank_angle) - l23(_flank_angle) * np.cos(_flank_angle)
+                        width / 2
+                        - r32 * np.sin(_alpha3)
+                        - r2 * np.cos(_gamma)
+                        - fw(_flank_angle)
+                        - l23(_flank_angle) * np.cos(_flank_angle)
                     ),
                 ]
             )
 
         sol = root(
-            f, np.array([np.pi / 4, np.pi / 4]),
+            f,
+            np.array([np.pi / 4, np.pi / 4]),
         )
 
         if not sol.success:
@@ -208,6 +227,7 @@ def solve_r123(
         flank_angle = alpha2 + alpha3
 
     else:
+
         def f(_alpha):
             _alpha2 = _alpha
             _alpha3 = flank_angle - _alpha
@@ -216,8 +236,12 @@ def solve_r123(
             _fw = width / 2 - r32 * np.sin(_alpha3) - r2 * np.cos(_gamma) - l23(flank_angle) * np.cos(flank_angle)
 
             return (
-                    depth - r3 + r32 * np.cos(_alpha3) + r2 * np.sin(_gamma)
-                    - _fw * np.tan(flank_angle) - l23(flank_angle) * np.sin(flank_angle)
+                depth
+                - r3
+                + r32 * np.cos(_alpha3)
+                + r2 * np.sin(_gamma)
+                - _fw * np.tan(flank_angle)
+                - l23(flank_angle) * np.sin(flank_angle)
             )
 
         sol = root_scalar(f, bracket=(MIN_ANGLE, MAX_ANGLE)).root
@@ -232,26 +256,25 @@ def solve_r123(
 
 
 def solve_r1234(
-        r1: float,
-        r2: float,
-        r3: float,
-        r4: float,
-        depth: float,
-        width: float,
-        indent: float,
-
-        pad_angle: float,
-
-        flank_angle: Optional[float] = None,
-        flank_width: Optional[float] = None,
-        flank_height: Optional[float] = None,
-        flank_length: Optional[float] = None,
+    r1: float,
+    r2: float,
+    r3: float,
+    r4: float,
+    depth: float,
+    width: float,
+    indent: float,
+    pad_angle: float,
+    flank_angle: Optional[float] = None,
+    flank_width: Optional[float] = None,
+    flank_height: Optional[float] = None,
+    flank_length: Optional[float] = None,
 ):
     def l23(_alpha):
         return r1 * np.tan((_alpha + pad_angle) / 2)
 
     if flank_angle is None:
         if flank_length is not None:
+
             def fw(_alpha):
                 return flank_length * np.cos(_alpha)
 
@@ -259,6 +282,7 @@ def solve_r1234(
                 return flank_length * np.sin(_alpha)
 
         elif flank_width is not None:
+
             def fw(_alpha):
                 return flank_width
 
@@ -266,6 +290,7 @@ def solve_r1234(
                 return flank_width * np.tan(_alpha)
 
         elif flank_height is not None:
+
             def fw(_alpha):
                 return flank_height / np.tan(_alpha)
 
@@ -273,6 +298,7 @@ def solve_r1234(
                 return flank_height
 
         else:
+
             def fw(_alpha):
                 return 0
 
@@ -290,17 +316,22 @@ def solve_r1234(
                 return np.array(
                     [
                         (
-                                depth - r3 + (r3 - r2) * np.cos(_alpha3 - _alpha4) + r2 * np.sin(_gamma)
-                                - fh(_flank_angle) - l23(_flank_angle) * np.sin(_flank_angle)
+                            depth
+                            - r3
+                            + (r3 - r2) * np.cos(_alpha3 - _alpha4)
+                            + r2 * np.sin(_gamma)
+                            - fh(_flank_angle)
+                            - l23(_flank_angle) * np.sin(_flank_angle)
                         ),
                         (
-                                width / 2 - (r3 - r2) * np.sin(_alpha3 - _alpha4) - r2 * np.cos(_gamma)
-                                - fw(_flank_angle) - l23(_flank_angle) * np.cos(_flank_angle)
-                                - (r3 + r4) * np.sin(_alpha4)
+                            width / 2
+                            - (r3 - r2) * np.sin(_alpha3 - _alpha4)
+                            - r2 * np.cos(_gamma)
+                            - fw(_flank_angle)
+                            - l23(_flank_angle) * np.cos(_flank_angle)
+                            - (r3 + r4) * np.sin(_alpha4)
                         ),
-                        (
-                                indent - (r3 + r4) * (1 - np.cos(_alpha4))
-                        )
+                        (indent - (r3 + r4) * (1 - np.cos(_alpha4))),
                     ]
                 )
             else:
@@ -308,24 +339,33 @@ def solve_r1234(
                 return np.array(
                     [
                         (
-                                depth - r2 * (1 - np.cos(_flank_angle))
-                                - fh(_flank_angle) - l23(_flank_angle) * np.sin(_flank_angle)
+                            depth
+                            - r2 * (1 - np.cos(_flank_angle))
+                            - fh(_flank_angle)
+                            - l23(_flank_angle) * np.sin(_flank_angle)
                         ),
                         (
-                                width / 2 - r2 * np.sin(_flank_angle)
-                                - fw(_flank_angle) - l23(_flank_angle) * np.cos(_flank_angle)
-                                - r4 * np.sin(_alpha4) - r3 * np.cos(_gamma)
-                                - (r2 - r3) * np.sin(_alpha2 - _flank_angle)
+                            width / 2
+                            - r2 * np.sin(_flank_angle)
+                            - fw(_flank_angle)
+                            - l23(_flank_angle) * np.cos(_flank_angle)
+                            - r4 * np.sin(_alpha4)
+                            - r3 * np.cos(_gamma)
+                            - (r2 - r3) * np.sin(_alpha2 - _flank_angle)
                         ),
                         (
-                                indent - r4 * (1 - np.cos(_alpha4)) + r3 * np.sin(_gamma)
-                                + (r2 - r3) * np.cos(_alpha4 - _alpha3) - r2
-                        )
+                            indent
+                            - r4 * (1 - np.cos(_alpha4))
+                            + r3 * np.sin(_gamma)
+                            + (r2 - r3) * np.cos(_alpha4 - _alpha3)
+                            - r2
+                        ),
                     ]
                 )
 
         sol = root(
-            f, np.array([np.pi / 4, np.pi / 4, np.pi / 4]),
+            f,
+            np.array([np.pi / 4, np.pi / 4, np.pi / 4]),
         )
 
         if not sol.success:
@@ -337,6 +377,7 @@ def solve_r1234(
         flank_angle = alpha2 + alpha3 - alpha4
 
     else:
+
         def f(_alpha):
             _alpha2 = _alpha[0]
             _alpha3 = _alpha[1]
@@ -348,17 +389,20 @@ def solve_r1234(
             return np.array(
                 [
                     (
-                            depth - r3 + (r3 - r2) * np.cos(_alpha3 - _alpha4) + r2 * np.sin(_gamma)
-                            - _fw * np.tan(flank_angle) - l23(flank_angle) * np.sin(flank_angle)
+                        depth
+                        - r3
+                        + (r3 - r2) * np.cos(_alpha3 - _alpha4)
+                        + r2 * np.sin(_gamma)
+                        - _fw * np.tan(flank_angle)
+                        - l23(flank_angle) * np.sin(flank_angle)
                     ),
-                    (
-                            indent - (r3 + r4) * (1 - np.cos(_alpha4))
-                    )
+                    (indent - (r3 + r4) * (1 - np.cos(_alpha4))),
                 ]
             )
 
         sol = root(
-            f, np.array([np.pi / 4, np.pi / 4]),
+            f,
+            np.array([np.pi / 4, np.pi / 4]),
         )
 
         if not sol.success:
@@ -377,14 +421,14 @@ def solve_r1234(
 
 
 def solve_box_like(
-        r2: float,
-        r4: float,
-        depth: float,
-        indent: float,
-        ground_width: Optional[float],
-        even_ground_width: Optional[float],
-        usable_width: Optional[float],
-        flank_angle: Optional[float],
+    r2: float,
+    r4: float,
+    depth: float,
+    indent: float,
+    ground_width: Optional[float],
+    even_ground_width: Optional[float],
+    usable_width: Optional[float],
+    flank_angle: Optional[float],
 ):
     alpha4 = np.arccos(1 - indent / (r2 + r4))
 
@@ -393,6 +437,7 @@ def solve_box_like(
             if ground_width is not None:
                 flank_angle = np.arctan(depth / (usable_width - ground_width) * 2)
             elif even_ground_width is not None:
+
                 def f(_alpha):
                     _ground_width = even_ground_width + 2 * ((r4 + r2) * np.sin(alpha4) + r2 * np.tan(_alpha / 2))
                     return depth - (usable_width - _ground_width) / 2 * np.tan(_alpha)
@@ -424,5 +469,5 @@ def solve_box_like(
         usable_width=usable_width,
         flank_angle=flank_angle,
         even_ground_width=even_ground_width,
-        alpha4=alpha4
+        alpha4=alpha4,
     )
