@@ -6,3 +6,14 @@ from .oval_3radii import Oval3RadiiGroove
 from .oval_3radii_flanked import Oval3RadiiFlankedGroove
 from .upset_oval import UpsetOvalGroove
 from .constricted_circular_oval import ConstrictedCircularOvalGroove
+
+__all__ = [
+    "CircularOvalGroove",
+    "FlatOvalGroove",
+    "SwedishOvalGroove",
+    "ConstrictedSwedishOvalGroove",
+    "Oval3RadiiGroove",
+    "Oval3RadiiFlankedGroove",
+    "UpsetOvalGroove",
+    "ConstrictedCircularOvalGroove",
+]
