@@ -5,18 +5,20 @@ import numpy as np
 from ..generic_elongation import GenericElongationGroove
 from ..generic_elongation_solvers import solve_r124
 
+__all__ = ["CircularOvalGroove"]
+
 
 class CircularOvalGroove(GenericElongationGroove):
     """Represents an oval-shaped groove with one main radius."""
 
     def __init__(
-            self,
-            r1: float,
-            r2: Optional[float] = None,
-            depth: Optional[float] = None,
-            usable_width: Optional[float] = None,
-            pad_angle: float = 0,
-            **kwargs
+        self,
+        r1: float,
+        r2: Optional[float] = None,
+        depth: Optional[float] = None,
+        usable_width: Optional[float] = None,
+        pad_angle: float = 0,
+        **kwargs,
     ):
         """
         Give exactly two of ``r2``, ``depth`` or ``usable_width``.
@@ -33,9 +35,13 @@ class CircularOvalGroove(GenericElongationGroove):
         sol = solve_r124(r1=r1, r2=r2, depth=depth, width=usable_width, pad_angle=pad_angle)
 
         super().__init__(
-            r2=sol["r2"], depth=sol["depth"], usable_width=sol["width"], flank_angle=sol["alpha"],
-            r1=r1, pad_angle=pad_angle,
-            **kwargs
+            r2=sol["r2"],
+            depth=sol["depth"],
+            usable_width=sol["width"],
+            flank_angle=sol["alpha"],
+            r1=r1,
+            pad_angle=pad_angle,
+            **kwargs,
         )
 
     @property
