@@ -5,23 +5,25 @@ import numpy as np
 from ..generic_elongation import GenericElongationGroove
 from ..generic_elongation_solvers import solve_box_like
 
+__all__ = ["ConstrictedSwedishOvalGroove"]
+
 
 class ConstrictedSwedishOvalGroove(GenericElongationGroove):
     """Represents a hexagonal-shaped groove with an indented ground that is used like an oval groove (swedish oval)."""
 
     def __init__(
-            self,
-            r1: float,
-            r2: float,
-            r4: float,
-            depth: float,
-            indent: float,
-            ground_width: Optional[float] = None,
-            even_ground_width: Optional[float] = None,
-            usable_width: Optional[float] = None,
-            flank_angle: Optional[float] = None,
-            pad_angle: float = 0,
-            **kwargs
+        self,
+        r1: float,
+        r2: float,
+        r4: float,
+        depth: float,
+        indent: float,
+        ground_width: Optional[float] = None,
+        even_ground_width: Optional[float] = None,
+        usable_width: Optional[float] = None,
+        flank_angle: Optional[float] = None,
+        pad_angle: float = 0,
+        **kwargs,
     ):
         """
         Exactly two of ``ground_width``, ``even_ground_width``, ``usable_width`` and ``flank_angle`` must be given,
@@ -46,15 +48,17 @@ class ConstrictedSwedishOvalGroove(GenericElongationGroove):
             flank_angle = np.deg2rad(flank_angle)
 
         sol = solve_box_like(
-            r2=r2, r4=r4, depth=depth, ground_width=ground_width, usable_width=usable_width, flank_angle=flank_angle,
-            indent=indent, even_ground_width=even_ground_width
+            r2=r2,
+            r4=r4,
+            depth=depth,
+            ground_width=ground_width,
+            usable_width=usable_width,
+            flank_angle=flank_angle,
+            indent=indent,
+            even_ground_width=even_ground_width,
         )
 
-        super().__init__(
-            r1=r1, r2=r2, r4=r4, pad_angle=np.deg2rad(pad_angle), indent=indent,
-            **sol,
-            **kwargs
-        )
+        super().__init__(r1=r1, r2=r2, r4=r4, pad_angle=np.deg2rad(pad_angle), indent=indent, **sol, **kwargs)
 
     @property
     def classifiers(self):
