@@ -1,15 +1,24 @@
 import math
 from typing import Optional, Union, Callable
-from collections.abc import Iterable, Collection, Set
+from collections.abc import Set
 
 import numpy as np
 from shapely.affinity import translate, rotate
 from shapely.geometry import Point, LinearRing, Polygon, LineString
-from shapely.ops import clip_by_rect, unary_union
+from shapely.ops import clip_by_rect
 
+from ..config import Config
 from ..grooves import GrooveBase
 from ..hooks import HookHost, Hook
 
+__all__ = [
+    "Profile",
+    "RoundProfile",
+    "DiamondProfile",
+    "BoxProfile",
+    "SquareProfile",
+]
+
 
 class Profile(HookHost):
     """Represents a profile aka a workpiece state."""
@@ -17,6 +26,9 @@ class Profile(HookHost):
     cross_section = Hook[Polygon]()
     """Shape of the profile's cross-section."""
 
+    technologically_orientated_cross_section = Hook[Polygon]()
+    """Shape of the profile's cross-section with technologically correct orientation."""
+
     classifiers = Hook[Set[str]]()
     """Classifiers of the profile's shape's type."""
 
@@ -47,6 +59,9 @@ class Profile(HookHost):
     equivalent_width = Hook[float]()
     """Width of the equivalent rectangle."""
 
+    equivalent_radius = Hook[float]()
+    """Radius of a equivalent round."""
+
     temperature = Hook[float]()
     """Mean temperature of the profile cross-section."""
 
@@ -87,6 +102,9 @@ class Profile(HookHost):
     grain_size = Hook[float]()
     """Average grain size of the profile's material."""
 
+    astm_grain_size_number = Hook[float]()
+    """ASTM grain size number, assuming grains are round."""
+
     heat_penetration_number = Hook[float]()
     """Mean heat penetration number of the profile material."""
 
@@ -94,15 +112,77 @@ class Profile(HookHost):
     """Mean thermal diffusivity of the profile material."""
 
     chemical_composition = Hook[dict[str, float]]()
-    """Chemical composition of the profile's material as dict of element symbols to atom fractions (0 to 1)."""
+    """Chemical composition of the profile's material as dict of element symbols to atom fractions (0 to 1).
+    The key of the dict should correspond to the nomenclature of the TDB (Thermodynamic Data Base file).
+    This means only capital letters and abbreviations according to the periodic table of the elements."""
 
     microstructure_composition = Hook[dict[str, float]]()
-    """Phase resp. constituent composition of the profile's material 
+    """Phase resp. constituent composition of the profile's material
     as dict of constituent names to volume fractions (0 to 1)."""
 
     scale_thickness = Hook[float]()
     """Thickness of the scale covering the profile."""
 
+    longitudinal_stress = Hook[float]()
+    """Normal stress (principal stress) in rolling (x) direction. Positive means tension, negative pressure."""
+
+    altitudinal_stress = Hook[float]()
+    """Normal stress (principal stress) in thickness (y) direction. Positive means tension, negative pressure."""
+
+    latitudinal_stress = Hook[float]()
+    """Normal stress (principal stress) in width (z) direction. Positive means tension, negative pressure."""
+
+    longitudinal_strain = Hook[float]()
+    """Logarithmic normal strain (principal strain) in rolling (x) direction."""
+
+    altitudinal_strain = Hook[float]()
+    """Logarithmic normal strain (principal strain) in thickness (y) direction."""
+
+    latitudinal_strain = Hook[float]()
+    """Logarithmic normal strain (principal strain) in width (z) direction."""
+
+    hydrostatic_stress = Hook[float]()
+    """Hydrodynamic Stress."""
+
+    equivalent_stress = Hook[float]()
+    """Equivalent Stress."""
+
+    normal_stress = Hook[float]()
+    """Normal Stress acting between profile and tooling."""
+
+    longitudinal_contact_friction = Hook[float]()
+    """Contact friction between profile and tooling in rolling (x) direction."""
+
+    latitudinal_contact_friction = Hook[float]()
+    """Contact friction between profile and tooling in width (z) direction."""
+
+    deformation_activation_energy = Hook[float]()
+    """Activation energy of deformation especially for calculation of Zener-Holomon-Parameter."""
+
+    martensite_start_temperature = Hook[float]()
+    """Martensite start temperature for the given chemical composition of the profile."""
+
+    martensite_finish_temperature = Hook[float]()
+    """Martensite finish temperature for the given chemical composition of the profile."""
+
+    bainite_start_temperature = Hook[float]()
+    """Bainite start temperature for the given chemical composition of the profile."""
+
+    bainite_finish_temperature = Hook[float]()
+    """Bainite finish temperature for the given chemical composition of the profile."""
+
+    ae1_temperature = Hook[float]()
+    """Temperature at which austenite starts to transform into a mixture of ferrite and cementite during cooling."""
+
+    ae3_temperature = Hook[float]()
+    """Temperature above which the transformation of austenite into a mixture of ferrite and cementite is complete during cooling."""
+
+    vickers_hardness = Hook[float]()
+    """Vickers hardness of the cold profile material."""
+
+    mass_per_meter = Hook[float]()
+    """Weight of one meter of the profile."""
+
     def __init__(self, **kwargs):
         """Using the ``__init__`` is not recommended, use one of the factory class methods instead."""
         self.t = 0
@@ -111,14 +191,14 @@ class Profile(HookHost):
 
     @classmethod
     def from_groove(
-            cls,
-            groove: GrooveBase,
-            width: Optional[float] = None,
-            filling: Optional[float] = None,
-            height: Optional[float] = None,
-            gap: Optional[float] = None,
-            **kwargs
-    ) -> 'Profile':
+        cls,
+        groove: GrooveBase,
+        width: Optional[float] = None,
+        filling: Optional[float] = None,
+        height: Optional[float] = None,
+        gap: Optional[float] = None,
+        **kwargs,
+    ) -> "Profile":
         """
         Create a profile instance based on a given groove.
         The dimensioning of the profile is determined by the parameters ``width``, ``filling``, ``height`` and ``gap``.
@@ -149,13 +229,7 @@ class Profile(HookHost):
         else:
             raise TypeError("either 'gap' or 'height' must be given")
 
-        if (
-                filling <= 0
-                or width <= 0
-                or height <= 0
-                or gap < 0
-
-        ):
+        if filling <= 0 or width <= 0 or height <= 0 or gap < 0:
             raise ValueError("argument value(s) out of range")
 
         if filling > 1:
@@ -165,40 +239,22 @@ class Profile(HookHost):
         upper_contour_line = translate(groove.contour_line, yoff=gap / 2)
         lower_contour_line = rotate(upper_contour_line, angle=180, origin=(0, 0))
 
-        poly = Polygon(
-            np.concatenate(
-                [
-                    upper_contour_line.coords,
-                    lower_contour_line.coords
-                ]
-            )
-        )
+        poly = Polygon(np.concatenate([upper_contour_line.coords, lower_contour_line.coords]))
 
         if (
-                # one percent tolerance to bypass discretization issues
-                - width / 2 < poly.bounds[0] * 1.01
-                or width / 2 > poly.bounds[2] * 1.01
+            # one percent tolerance to bypass discretization issues
+            -width / 2 < poly.bounds[0] * 1.01 or width / 2 > poly.bounds[2] * 1.01
         ):
             raise ValueError(
-                "Profile's width can not be larger than its contour lines."
-                "May be caused by critical overfilling."
+                "Profile's width can not be larger than its contour lines." "May be caused by critical overfilling."
             )
 
         polygon = clip_by_rect(poly, -width / 2, -math.inf, width / 2, math.inf)
 
-        return cls(
-            cross_section=polygon,
-            classifiers=set(groove.classifiers),
-            **kwargs
-        )
+        return cls(cross_section=refine_cross_section(polygon), classifiers=set(groove.classifiers), **kwargs)
 
     @classmethod
-    def from_polygon(
-            cls,
-            cross_section: Polygon,
-            classifiers: Set[str],
-            **kwargs
-    ) -> 'Profile':
+    def from_polygon(cls, cross_section: Polygon, classifiers: Set[str], **kwargs) -> "Profile":
         """
         Creates a custom profile from a shapely polygon object.
 
@@ -219,19 +275,10 @@ class Profile(HookHost):
         if len(cross_section.interiors) > 0:
             raise ValueError("The cross-section must not contain holes.")
 
-        return cls(
-            cross_section=cross_section,
-            classifiers=set(classifiers),
-            **kwargs
-        )
+        return cls(cross_section=cross_section, classifiers=set(classifiers), **kwargs)
 
     @classmethod
-    def round(
-            cls,
-            radius: Optional[float] = None,
-            diameter: Optional[float] = None,
-            **kwargs
-    ) -> 'RoundProfile':
+    def round(cls, radius: Optional[float] = None, diameter: Optional[float] = None, **kwargs) -> "RoundProfile":
         """
         Creates a round shaped profile (a real circle round, without imperfections of round grooves).
         Give exactly one of ``radius`` and ``diameter``.
@@ -247,12 +294,8 @@ class Profile(HookHost):
 
     @classmethod
     def square(
-            cls,
-            side: Optional[float] = None,
-            diagonal: Optional[float] = None,
-            corner_radius: float = 0,
-            **kwargs
-    ) -> 'SquareProfile':
+        cls, side: Optional[float] = None, diagonal: Optional[float] = None, corner_radius: float = 0, **kwargs
+    ) -> "SquareProfile":
         """
         Creates a square shaped profile (a real square with rounded corners, without imperfections of square grooves).
         A square is oriented to stand on its corner, use :py:meth:`box` to create a side standing one.
@@ -271,13 +314,7 @@ class Profile(HookHost):
         return SquareProfile(side, diagonal, corner_radius, **kwargs)
 
     @classmethod
-    def box(
-            cls,
-            height: float,
-            width: float,
-            corner_radius: float = 0,
-            **kwargs
-    ) -> 'BoxProfile':
+    def box(cls, height: float, width: float, corner_radius: float = 0, **kwargs) -> "BoxProfile":
         """
         Creates a box shaped profile (a real rectangular shape with rounded corners,
         without imperfections of box grooves).
@@ -293,13 +330,7 @@ class Profile(HookHost):
         return BoxProfile(height, width, corner_radius, **kwargs)
 
     @classmethod
-    def diamond(
-            cls,
-            height: float,
-            width: float,
-            corner_radius: float = 0,
-            **kwargs
-    ) -> 'DiamondProfile':
+    def diamond(cls, height: float, width: float, corner_radius: float = 0, **kwargs) -> "DiamondProfile":
         """
         Creates a diamond shaped profile (a real diamond shape with rounded corners,
         without imperfections of diamond grooves).
@@ -314,25 +345,50 @@ class Profile(HookHost):
 
         return DiamondProfile(height, width, corner_radius, **kwargs)
 
+    @classmethod
+    def hexagon(
+        cls,
+        side: Optional[float] = None,
+        height: Optional[float] = None,
+        diagonal: Optional[float] = None,
+        corner_radius: float = 0,
+        **kwargs,
+    ) -> "HexagonProfile":
+        """
+        Creates a hexagonal shaped profile (a real hexagonal shape with rounded corners,
+        without imperfections of hexagonal grooves). A hexagon is oriented to stand on its side.
+        Give exactly one of ``side``, ``height`` and ``diagonal``.
+
+        :param side: the side length of the hexagonal profile, must be > 0
+        :param height: the height of the hexagonal profile when standing on the flat base, must be > 0
+        :param diagonal: the diagonal length of the hexagonal profile (corner-to-corner distance)
+        :param corner_radius: the radius of the hexagon's corners, must be >= 0, <= diagonal / 2
+        :param kwargs: additional keyword arguments to be passed to the Profile constructor
+        :raises TypeError: on invalid argument combinations
+        :raises ValueError: if arguments are out of range
+        """
+
+        return HexagonProfile(side, height, diagonal, corner_radius, **kwargs)
+
     def local_height(self, z: float) -> float:
         coords = np.array([(1, -1), (1, 1)]) * (z, self.height)
 
-        vline = LineString(
-            coords
-        )
+        vline = LineString(coords)
 
-        intersection = vline.intersection(self.cross_section)
+        tolerance = 1e-12
+
+        intersection = vline.intersection(self.cross_section.buffer(tolerance))
 
         return intersection.length
 
     def local_width(self, y: float) -> float:
         coords = np.array([(-1, 1), (1, 1)]) * (self.width, y)
 
-        hline = LineString(
-            coords
-        )
+        hline = LineString(coords)
 
-        intersection = hline.intersection(self.cross_section)
+        tolerance = 1e-12
+
+        intersection = hline.intersection(self.cross_section.buffer(tolerance))
 
         return intersection.length
 
@@ -353,23 +409,14 @@ class Profile(HookHost):
 
         except ValueError:
             try:
-                return key in {
-                    _format(k)
-                    for k in self.material
-                }
+                return key in {_format(k) for k in self.material}
             except TypeError:
                 raise ValueError("Value of self.material is neither a string or a collection of strings.")
 
-    def plot(self, **kwargs):
-        try:
-            import matplotlib.pyplot as plt
-        except ImportError as e:
-            raise RuntimeError(
-                "This method is only available if matplotlib is installed in the environment. "
-                "You may install it using the 'plot' extra of pyroll-core."
-            ) from e
+    def _plot_matplotlib_(self):
+        import matplotlib.pyplot as plt
 
-        fig: plt.Figure = plt.figure(**kwargs)
+        fig: plt.Figure = plt.figure()
         ax: plt.Axes = fig.subplots()
 
         ax.set_ylabel("y")
@@ -382,14 +429,24 @@ class Profile(HookHost):
         ax.fill(*self.cross_section.boundary.xy, color="k", alpha=0.5)
         return fig
 
+    def _plot_plotly_(self):
+        import plotly.express as px
+
+        fig = px.line(
+            x=self.cross_section.boundary.xy[0],
+            y=self.cross_section.boundary.xy[1],
+            labels={"y": "y", "x": "z"},
+        )
+
+        fig.data[0].fill = "toself"
+
+        fig.update_yaxes(scaleanchor="x", scaleratio=1)
+
+        return fig
+
 
 class RoundProfile(Profile):
-    def __init__(
-            self,
-            radius: Optional[float] = None,
-            diameter: Optional[float] = None,
-            **kwargs
-    ):
+    def __init__(self, radius: Optional[float] = None, diameter: Optional[float] = None, **kwargs):
         """
         Creates a round shaped profile (a real circle round, without imperfections of round grooves).
         Give exactly one of ``radius`` and ``diameter``.
@@ -417,11 +474,7 @@ class RoundProfile(Profile):
         center = Point((0, 0))
         circle = center.buffer(radius)
 
-        super().__init__(
-            cross_section=circle,
-            classifiers={"round"},
-            **kwargs
-        )
+        super().__init__(cross_section=refine_cross_section(circle), classifiers={"round"}, **kwargs)
 
     @property
     def radius(self):
@@ -439,13 +492,7 @@ class RoundProfile(Profile):
 
 
 class BoxProfile(Profile):
-    def __init__(
-            self,
-            height: float,
-            width: float,
-            corner_radius: float = 0,
-            **kwargs
-    ):
+    def __init__(self, height: float, width: float, corner_radius: float = 0, **kwargs):
         """
         Creates a box shaped profile (a real rectangular shape with rounded corners,
         without imperfections of box grooves).
@@ -458,29 +505,18 @@ class BoxProfile(Profile):
         :raises ValueError: if arguments are out of range
         """
 
-        if (
-                height <= 0
-                or width <= 0
-                or corner_radius < 0
-                or corner_radius > height / 2
-                or corner_radius > width / 2
-        ):
+        if height <= 0 or width <= 0 or corner_radius < 0 or corner_radius > height / 2 or corner_radius > width / 2:
             raise ValueError("argument value(s) out of range")
 
         self._corner_radius = corner_radius
 
         line = LinearRing(
-            np.array([(1, -1), (1, 1), (-1, 1), (-1, -1)])
-            * (width / 2 - corner_radius, height / 2 - corner_radius)
+            np.array([(1, -1), (1, 1), (-1, 1), (-1, -1)]) * (width / 2 - corner_radius, height / 2 - corner_radius)
         )
         polygon = Polygon(line)
         polygon = polygon.buffer(corner_radius)
 
-        super().__init__(
-            cross_section=polygon,
-            classifiers={"box"},
-            **kwargs
-        )
+        super().__init__(cross_section=refine_cross_section(polygon), classifiers={"box"}, **kwargs)
 
     @property
     def corner_radius(self):
@@ -493,13 +529,7 @@ class BoxProfile(Profile):
 
 
 class DiamondProfile(Profile):
-    def __init__(
-            self,
-            height: float,
-            width: float,
-            corner_radius: float = 0,
-            **kwargs
-    ):
+    def __init__(self, height: float, width: float, corner_radius: float = 0, **kwargs):
         """
         Creates a diamond shaped profile (a real diamond shape with rounded corners,
         without imperfections of diamond grooves).
@@ -512,29 +542,18 @@ class DiamondProfile(Profile):
         :raises ValueError: if arguments are out of range
         """
 
-        if (
-                height <= 0
-                or width <= 0
-                or corner_radius < 0
-                or corner_radius > height / 2
-                or corner_radius > width / 2
-        ):
+        if height <= 0 or width <= 0 or corner_radius < 0 or corner_radius > height / 2 or corner_radius > width / 2:
             raise ValueError("argument value(s) out of range")
 
         self._corner_radius = corner_radius
 
         line = LinearRing(
-            np.array([(1, 0), (0, 1), (-1, 0), (0, -1)])
-            * (width / 2 - corner_radius, height / 2 - corner_radius)
+            np.array([(1, 0), (0, 1), (-1, 0), (0, -1)]) * (width / 2 - corner_radius, height / 2 - corner_radius)
         )
         polygon = Polygon(line)
         polygon = polygon.buffer(corner_radius)
 
-        super().__init__(
-            cross_section=polygon,
-            classifiers={"diamond"},
-            **kwargs
-        )
+        super().__init__(cross_section=refine_cross_section(polygon), classifiers={"diamond"}, **kwargs)
 
     @property
     def corner_radius(self):
@@ -548,11 +567,7 @@ class DiamondProfile(Profile):
 
 class SquareProfile(Profile):
     def __init__(
-            self,
-            side: Optional[float] = None,
-            diagonal: Optional[float] = None,
-            corner_radius: float = 0,
-            **kwargs
+        self, side: Optional[float] = None, diagonal: Optional[float] = None, corner_radius: float = 0, **kwargs
     ):
         """
         Creates a square shaped profile (a real square with rounded corners, without imperfections of square grooves).
@@ -576,11 +591,7 @@ class SquareProfile(Profile):
         else:
             raise TypeError("either 'side' or 'diagonal' must be given")
 
-        if (
-                side <= 0
-                or corner_radius < 0
-                or corner_radius > side / 2
-        ):
+        if side <= 0 or corner_radius < 0 or corner_radius > side / 2:
             raise ValueError("argument value(s) out of range")
 
         self._side = side
@@ -591,11 +602,7 @@ class SquareProfile(Profile):
         polygon = Polygon(line)
         polygon = polygon.buffer(corner_radius)
 
-        super().__init__(
-            cross_section=polygon,
-            classifiers={"square", "diamond"},
-            **kwargs
-        )
+        super().__init__(cross_section=refine_cross_section(polygon), classifiers={"square", "diamond"}, **kwargs)
 
     @property
     def side(self):
@@ -614,8 +621,91 @@ class SquareProfile(Profile):
 
     @property
     def __attrs__(self):
-        return super().__attrs__ | dict(
-            side=self._side,
-            diagonal=self._diagonal,
-            corner_radius=self._corner_radius
+        return super().__attrs__ | dict(side=self._side, diagonal=self._diagonal, corner_radius=self._corner_radius)
+
+
+class HexagonProfile(Profile):
+    def __init__(
+        self,
+        side: Optional[float] = None,
+        height: Optional[float] = None,
+        diagonal: Optional[float] = None,
+        corner_radius: float = 0,
+        **kwargs,
+    ):
+        """
+        Creates a hexagonal shaped profile (a real hexagonal shape with rounded corners,
+        without imperfections of hexagonal grooves). A hexagon is oriented to stand on its side.
+        Give exactly one of ``side``, ``height`` and ``diagonal``.
+
+        :param side: the side length of the hexagonal profile, must be > 0
+        :param height: the height of the hexagonal profile when standing on the flat base, must be > 0
+        :param diagonal: the diagonal length of the hexagonal profile (corner-to-corner distance)
+        :param corner_radius: the radius of the hexagon's corners, must be >= 0, <= diagonal / 2
+        :param kwargs: additional keyword arguments to be passed to the Profile constructor
+        :raises TypeError: on invalid argument combinations
+        :raises ValueError: if arguments are out of range
+        """
+
+        if side is not None and diagonal is None and height is None:
+            height = side * np.sqrt(3)
+            diagonal = side * 2
+        elif diagonal is not None and side is None and height is None:
+            side = diagonal / 2
+            height = side / np.sqrt(3)
+        elif height is not None and side is None and diagonal is None:
+            side = height / np.sqrt(3)
+            diagonal = side * 2
+        else:
+            raise TypeError("either 'side', 'height' or 'diagonal' must be given")
+
+        if side <= 0 or height <= 0 or diagonal <= 0 or corner_radius < 0 or corner_radius > side / 2:
+            raise ValueError("argument value(s) out of range")
+
+        self._corner_radius = corner_radius
+        self._side = side
+        self._diagonal = diagonal
+
+        line = LinearRing(
+            np.array(
+                [
+                    (-1, 0),
+                    (-1 / 2, np.sqrt(3) / 2),
+                    (1 / 2, np.sqrt(3) / 2),
+                    (1, 0),
+                    (1 / 2, -np.sqrt(3) / 2),
+                    (-1 / 2, -np.sqrt(3) / 2),
+                ]
+            )
+            * (side, side)
         )
+        polygon = Polygon(line)
+        polygon = polygon.buffer(corner_radius)
+
+        super().__init__(cross_section=refine_cross_section(polygon), classifiers={"hexagon"}, **kwargs)
+
+    @property
+    def side(self):
+        """The side length of the hexagon profile."""
+        return self._side
+
+    @property
+    def diagonal(self):
+        """The diagonal between two flat sides of the hexagon profile."""
+        return self._diagonal
+
+    @property
+    def corner_radius(self):
+        """The radius of the profile's corners resp. edges."""
+        return self._corner_radius
+
+    @property
+    def __attrs__(self):
+        return super().__attrs__ | dict(side=self._side, diagonal=self._diagonal, corner_radius=self._corner_radius)
+
+
+def refine_cross_section(cross_section: Polygon):
+    if Config.PROFILE_CONTOUR_REFINEMENT < 1:
+        return cross_section
+
+    return cross_section.segmentize(cross_section.boundary.length / Config.PROFILE_CONTOUR_REFINEMENT)
