@@ -52,6 +52,19 @@ def box_diamond_45(self: Rotator):
         return 45
 
 
+@Rotator.rotation
+def flat_flat_0(self: Rotator):
+    if "3fold" not in self.next_roll_pass.classifiers:
+        if "flat" in self.in_profile.classifiers and "flat" in self.next_roll_pass.classifiers:
+            return 0
+
+
+@Rotator.rotation
+def box_flat_0(self: Rotator):
+    if "box" in self.in_profile.classifiers and "flat" in self.next_roll_pass.classifiers:
+        return 0
+
+
 @Rotator.rotation
 def square_flat_45(self: Rotator):
     if "square" in self.in_profile.classifiers and "flat" in self.next_roll_pass.classifiers:
