@@ -3,6 +3,8 @@ from typing import List, cast
 from ..hooks import Hook
 from ..disk_elements import DiskElementUnit
 
+__all__ = ["Transport"]
+
 
 class Transport(DiskElementUnit):
     """Represents a transport unit, e.g. an inter-rolling-stand gap, a furnace or cooling range."""
@@ -11,15 +13,15 @@ class Transport(DiskElementUnit):
     """Temperature of the surrounding atmosphere."""
 
     @property
-    def disk_elements(self) -> List['Transport.DiskElement']:
+    def disk_elements(self) -> List["Transport.DiskElement"]:
         """A list of disk elements used to subdivide this unit."""
-        return self._subunits
+        return list(self._subunits)
 
     class Profile(DiskElementUnit.Profile):
         """Represents a profile in context of a transport unit."""
 
         @property
-        def transport(self) -> 'Transport':
+        def transport(self) -> "Transport":
             """Reference to the transport. Alias for ``self.unit``."""
             return cast(Transport, self.unit)
 
@@ -33,7 +35,7 @@ class Transport(DiskElementUnit):
         """Represents a disk element in a roll pass."""
 
         @property
-        def transport(self) -> 'Transport':
+        def transport(self) -> "Transport":
             """Reference to the transport. Alias for ``self.parent``."""
             return cast(Transport, self.parent)
 
@@ -41,12 +43,12 @@ class Transport(DiskElementUnit):
             """Represents a profile in context of a disk element unit."""
 
             @property
-            def disk_element(self) -> 'Transport.DiskElement':
+            def disk_element(self) -> "Transport.DiskElement":
                 """Reference to the disk element. Alias for ``self.unit``"""
                 return cast(Transport.DiskElement, self.unit)
 
             @property
-            def transport(self) -> 'Transport':
+            def transport(self) -> "Transport":
                 """Reference to the transport. Alias for ``self.unit.parent``"""
                 return cast(Transport, self.unit.parent)
 
