@@ -1,6 +1,6 @@
 import copy
 import weakref
-from typing import Optional, Sequence, List, Iterable, SupportsIndex, Union
+from typing import Optional, Sequence, List, Iterable, SupportsIndex, Union, Callable, Self
 
 import numpy as np
 
@@ -8,6 +8,8 @@ from ..hooks import HookHost, Hook
 from ..profile import Profile as BaseProfile
 from timeit import default_timer as timer
 
+__all__ = ["Unit"]
+
 
 class Unit(HookHost):
     """Base class for units."""
@@ -45,6 +47,12 @@ class Unit(HookHost):
     energy_consumption = Hook[float]()
     """Energy consumption of this unit per produced mass."""
 
+    pre_processors: list[Callable[[Self], "Unit"]] = []
+    """List of unit factories to use as pre-processors to modify the in-profile given to ``solve``."""
+
+    post_processors: list[Callable[[Self], "Unit"]] = []
+    """List of unit factories to use as post-processors to modify the out-profile returned by ``solve``."""
+
     def __init__(self, label: str = "", parent=None, **kwargs):
         super().__init__()
         self.label = label
@@ -54,6 +62,12 @@ class Unit(HookHost):
 
         self._parent = weakref.ref(parent) if parent is not None else None
 
+        self.convergence_history = []
+        """List to store the convergence history of the unit."""
+
+        self.global_iterator = 1
+        """Global iterator for the convergence history."""
+
         self.in_profile: Optional[Unit.InProfile] = None
         """The state of the incoming profile."""
 
@@ -132,10 +146,38 @@ class Unit(HookHost):
 
         :param in_profile: the incoming state passed to :py:meth:`solve`
         """
+
+        for pre_processor_factory in self._yield_pre_processors():
+            pre_processor = pre_processor_factory(self)
+
+            if pre_processor is None:
+                continue
+
+            self.logger.debug(f"Running pre-processor '{pre_processor.label}'.")
+            in_profile = pre_processor.solve(in_profile)
+
         self.in_profile = self.InProfile(self, in_profile)
         if not self.out_profile:
             self.out_profile = self.OutProfile(self, in_profile)
 
+    def __init_subclass__(cls, **kwargs):
+        cls.pre_processors = []
+        cls.post_processors = []
+
+    def _yield_pre_processors(self):
+        for s in reversed(type(self).__mro__):
+            inits = getattr(s, "pre_processors", None)
+
+            if inits is not None:
+                yield from inits
+
+    def _yield_post_processors(self):
+        for s in reversed(type(self).__mro__):
+            inits = getattr(s, "post_processors", None)
+
+            if inits is not None:
+                yield from inits
+
     def get_root_hook_results(self):
         in_profile_results = self.in_profile.evaluate_and_set_hooks()
         out_profile_results = self.out_profile.evaluate_and_set_hooks()
@@ -172,9 +214,18 @@ class Unit(HookHost):
             self.out_profile.reevaluate_cache()
             current_results = self.get_root_hook_results()
 
+            residuum = np.max(np.abs(current_results - self._old_results) / (np.abs(self._old_results) + 1e-12))
+
+            self.convergence_history.append({
+                "iteration": self.global_iterator,
+                "residuum": residuum,
+                "label": self.label
+            })
+
+            self.global_iterator += 1
+
             if np.all(
-                    np.abs(current_results - self._old_results)
-                    <= np.abs(self._old_results) * self.iteration_precision
+                np.abs(current_results - self._old_results) <= np.abs(self._old_results) * self.iteration_precision
             ):
                 self.logger.info(f"Finished solving of {self} after {i} iterations.")
                 break
@@ -187,26 +238,31 @@ class Unit(HookHost):
                 f" Continuing anyway."
             )
 
+        out_profile = BaseProfile(**{k: v for k, v in self.out_profile.__dict__.items() if not k.startswith("_")})
+
+        for post_processor_factory in self._yield_post_processors():
+            post_processor = post_processor_factory(self)
+
+            if post_processor is None:
+                continue
+
+            self.logger.debug(f"Running post-processor '{post_processor.label}'.")
+            out_profile = post_processor.solve(out_profile)
+
         end = timer()
         self.logger.info(f"Solution took {end - start:.3f} s.")
 
-        result = BaseProfile(
-            **{
-                k: v for k, v in self.out_profile.__dict__.items()
-                if not k.startswith("_")
-            }
-        )
-        return result
+        return out_profile
 
     @property
-    def parent(self) -> Optional['Unit']:
+    def parent(self) -> Optional["Unit"]:
         """Reference to the parent unit, if applicable, else None."""
         if self._parent is None:
             return None
         return self._parent()
 
     @parent.setter
-    def parent(self, value: 'Unit'):
+    def parent(self, value: "Unit"):
         """Sets Reference to the parent unit."""
         if value is None:
             self._parent = None
@@ -214,23 +270,34 @@ class Unit(HookHost):
             self._parent = weakref.ref(value)
 
     @property
-    def subunits(self) -> List['Unit']:
+    def subunits(self) -> List["Unit"]:
         """List of the subunits."""
         return self._subunits
 
+    @property
+    def profiles(self) -> List[BaseProfile]:
+        """Returns a list of all profiles appearing in this unit.
+        The list contains in and out profiles of all subunits and this unit itself in the order of rolling direction.
+        This property recurses into all subunits."""
+
+        def _yield_profiles():
+            yield self.in_profile
+            for u in self._subunits:
+                yield from u.profiles
+            yield self.out_profile
+
+        return list(_yield_profiles())
+
     class Profile(BaseProfile):
         """Represents a profile in context of a unit."""
 
-        def __init__(self, unit: 'Unit', template: BaseProfile):
-            kwargs = dict(
-                e for e in template.__dict__.items()
-                if not e[0].startswith("_")
-            )
+        def __init__(self, unit: "Unit", template: BaseProfile):
+            kwargs = dict(e for e in template.__dict__.items() if not e[0].startswith("_"))
             self._unit = weakref.ref(unit)
             super().__init__(**kwargs)
 
         @property
-        def unit(self) -> 'Unit':
+        def unit(self) -> "Unit":
             """Reference to the parent unit, if applicable, else None."""
             return self._unit()
 
@@ -249,26 +316,26 @@ class Unit(HookHost):
     class _SubUnitsList(list):
         """Specialized list for holding the units of a pass sequence."""
 
-        def __init__(self, owner: 'Unit', units: Sequence['Unit']):
+        def __init__(self, owner: "Unit", units: Sequence["Unit"]):
             super().__init__(units)
             self._owner = weakref.ref(owner)
             for u in self:
                 u.parent = owner
 
-        def append(self, unit: 'Unit') -> None:
+        def append(self, unit: "Unit") -> None:
             unit.parent = self._owner()
             super().append(unit)
 
-        def extend(self, units: Iterable['Unit']) -> None:
+        def extend(self, units: Iterable["Unit"]) -> None:
             for u in units:
                 u.parent = self._owner()
             super().extend(units)
 
-        def insert(self, i: Union[SupportsIndex, slice], unit: 'Unit') -> None:
+        def insert(self, i: Union[SupportsIndex, slice], unit: "Unit") -> None:
             unit.parent = self._owner()
             super().insert(i, unit)
 
-        def pop(self, i: Union[SupportsIndex, slice] = ...) -> 'Unit':
+        def pop(self, i: Union[SupportsIndex, slice] = ...) -> "Unit":
             unit = super().pop(i)
             unit.parent = None
             return unit
@@ -278,10 +345,10 @@ class Unit(HookHost):
                 u.parent = None
             super().clear()
 
-        def copy(self) -> 'Unit._SubUnitsList':
+        def copy(self) -> "Unit._SubUnitsList":
             return self.__init__(self._owner(), self)
 
-        def __setitem__(self, i: Union[SupportsIndex, slice], value: 'Unit'):
+        def __setitem__(self, i: Union[SupportsIndex, slice], value: "Unit"):
             current = self[i]
             if isinstance(current, list):
                 for u in current:
